=======
History
=======

0.2.1 (2017-05-31)
------------------

* Pulled out individual methods to objects for barcodes
* Building tests for some of objects

0.1.0 (2017-05-26)
------------------

* Initial Creation as Standalone package.

